@@ -58,6 +58,9 @@ void options::load_cfg(){
     configs<<"psx4m-cycle"<<"psx4m-frame"<<"psx4m-hwa"<<"psx4m-fps"<<"psx4m-fullscreen"<<"psx4m-afix";
     configs<<"pcsx-threadedspu"<<"pcsx-hwa"<<"pcsx-bios"<<"pcsx-frameskip";
     configs<<"accel";
+    configs<<"cdda" <<    "xa" <<    "rcnt"<<    "sio"<<    "spuir"<<    "vsync";
+    configs<<"fsaa";
+
     if (QFile::exists(path)){
 
         QFile file(path);
@@ -118,6 +121,28 @@ void options::load_cfg(){
                  case 13:
                       if (value=="1")ui->checkBox_9->setChecked(true);else ui->checkBox_9->setChecked(false);
                       break;
+                 case 14:
+                      if (value=="1")ui->checkBox_10->setChecked(true);else ui->checkBox_10->setChecked(false);
+                      break;
+                 case 15:
+                      if (value=="1")ui->checkBox_11->setChecked(true);else ui->checkBox_11->setChecked(false);
+                      break;
+                 case 16:
+                      if (value=="1")ui->checkBox_12->setChecked(true);else ui->checkBox_12->setChecked(false);
+                      break;
+                 case 17:
+                      if (value=="1")ui->checkBox_13->setChecked(true);else ui->checkBox_13->setChecked(false);
+                      break;
+                 case 18:
+                      if (value=="1")ui->checkBox_14->setChecked(true);else ui->checkBox_14->setChecked(false);
+                      break;
+                 case 19:
+                      if (value=="1")ui->checkBox_15->setChecked(true);else ui->checkBox_15->setChecked(false);
+                      break;
+                 case 20:
+                      if (value=="1")ui->checkBox_16->setChecked(true);else ui->checkBox_16->setChecked(false);
+                      break;
+
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -128,53 +153,63 @@ void options::load_cfg(){
              // checking
              psx4m_hwa_block();
 
-             current_config=QStringList();
-             if (ui->checkBox->isChecked())current_config<<"-nosound";
-             if (ui->checkBox_9->isChecked())current_config<<"-accel";
-
-             if (ui->radioButton_2->isChecked())
-             {
-                 current_core="pcsx";
-
-                 if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
-                 if (ui->checkBox_4->isChecked())current_config<<"-gles";
-                 if (ui->checkBox_5->isChecked())current_config<<"-bios";
-                 if (ui->comboBox_3->currentIndex()>0)
-                 current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
-                 current_config<<"-cdfile";
-
-             }
-             else{
-                 if (ui->comboBox->currentText()!="Disabled")current_config<<"-cyclemult"<<ui->comboBox->currentText();
-
-             if (ui->checkBox_2->isChecked())
-                 {
-                 current_core="psx4m-gles";
-
-                 }
-             else
-             {
-                 current_core="psx4m";
-                 if (ui->comboBox_2->currentText()!="Disabled")
-                     if (ui->comboBox_2->currentText()=="Auto")current_config<<"-autoskip";
-                             else current_config<<"-frameskip"<<ui->comboBox_2->currentText();
-
-                 if (ui->checkBox_6->isChecked())current_config<<"-showfps";
-                 if (ui->checkBox_7->isChecked())current_config<<"-fullscreen";
-                 if (ui->checkBox_8->isChecked())current_config<<"-abbeyfix";
-
-
-
-                       }
-             current_config<<"-runcd";
-         }
-
-
-
+             createCfg();
     }
 }
 
+
+void options::createCfg(){
+    current_config=QStringList();
+    if (ui->checkBox->isChecked())current_config<<"-nosound";
+    if (ui->checkBox_9->isChecked())current_config<<"-accel";
+
+    if (ui->checkBox_10->isChecked())current_config<<"-cdda";
+    if (ui->checkBox_11->isChecked())current_config<<"-xa";
+    if (ui->checkBox_12->isChecked())current_config<<"-rcnt";
+    if (ui->checkBox_13->isChecked())current_config<<"-sio";
+    if (ui->checkBox_14->isChecked())current_config<<"-spuirq";
+    if (ui->checkBox_15->isChecked())current_config<<"-vsync";
+
+    if (ui->radioButton_2->isChecked())
+    {
+        current_core="pcsx";
+
+        if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
+        if (ui->checkBox_4->isChecked())current_config<<"-gles";
+        if (ui->checkBox_5->isChecked())current_config<<"-bios"<<ui->comboBox_4->currentText()<<"-bdir"<<bios_path;;
+        if (ui->comboBox_3->currentIndex()>0)
+        current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
+        current_config<<"-cdfile";
+
+    }
+    else{
+        if (ui->comboBox->currentText()!="Disabled")current_config<<"-cyclemult"<<ui->comboBox->currentText();
+        current_config<<"-bios"<<ui->comboBox_4->currentText()<<"-bdir"<<bios_path;
+    if (ui->checkBox_2->isChecked())
+        {
+        current_core="psx4m-gles";
+
+        }
+    else
+    {
+        current_core="psx4m";
+        if (ui->comboBox_2->currentText()!="Disabled")
+            if (ui->comboBox_2->currentText()=="Auto")current_config<<"-autoskip";
+                    else current_config<<"-frameskip"<<ui->comboBox_2->currentText();
+
+        if (ui->checkBox_6->isChecked())current_config<<"-showfps";
+        if (ui->checkBox_7->isChecked())current_config<<"-fullscreen";
+        if (ui->checkBox_8->isChecked())current_config<<"-abbeyfix";
+
+
+
+              }
+    current_config<<"-runcd";
+}
+}
+
 void options::save_cfg(){
+    createCfg();
     QString path="";
     if (game!="")
         path=cfg_path+game;
@@ -195,7 +230,14 @@ void options::save_cfg(){
                    "pcsx-hwa=%11\n" \
                    "pcsx-bios=%12\n" \
                    "pcsx-frameskip=%13\n" \
-                   "accel=%14\n")
+                   "accel=%14\n" \
+                   "cdda=%15\n" \
+                   "xa=%16\n" \
+                   "rcnt=%17\n" \
+                   "sio=%18\n" \
+                   "spuirq=%19\n" \
+                   "vsync=%20\n" \
+                   "fsaa=%21\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -208,8 +250,16 @@ void options::save_cfg(){
             .arg(ui->checkBox_3->isChecked()?"1":"0")
             .arg(ui->checkBox_4->isChecked()?"1":"0")
             .arg(ui->checkBox_5->isChecked()?"1":"0")
-            .arg(ui->comboBox_3->currentText()
-.arg(ui->checkBox_9->isChecked()?"1":"0"))
+            .arg(ui->comboBox_3->currentText())
+.arg(ui->checkBox_9->isChecked()?"1":"0")
+.arg(ui->checkBox_10->isChecked()?"1":"0")
+.arg(ui->checkBox_11->isChecked()?"1":"0")
+.arg(ui->checkBox_12->isChecked()?"1":"0")
+.arg(ui->checkBox_13->isChecked()?"1":"0")
+.arg(ui->checkBox_14->isChecked()?"1":"0")
+.arg(ui->checkBox_15->isChecked()?"1":"0")
+        .arg(ui->checkBox_16->isChecked()?"1":"0")
+
 ;
 
     QFile file(path);
@@ -222,47 +272,6 @@ void options::save_cfg(){
 
          file.close();
 
-
-         current_config=QStringList();
-         if (ui->checkBox->isChecked())current_config<<"-nosound";
-         if (ui->checkBox_9->isChecked())current_config<<"-accel";
-
-         if (ui->radioButton_2->isChecked())
-         {
-             current_core="pcsx";
-
-             if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
-             if (ui->checkBox_4->isChecked())current_config<<"-gles";
-             if (ui->checkBox_5->isChecked())current_config<<"-bios";
-             if (ui->comboBox_3->currentIndex()>0)
-             current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
-             current_config<<"-cdfile";
-
-         }
-         else{
-             if (ui->comboBox->currentText()!="Disabled")current_config<<"-cyclemult"<<ui->comboBox->currentText();
-
-         if (ui->checkBox_2->isChecked())
-             {
-             current_core="psx4m-gles";
-
-             }
-         else
-         {
-             current_core="psx4m";
-             if (ui->comboBox_2->currentText()!="Disabled")
-                 if (ui->comboBox_2->currentText()=="Auto")current_config<<"-autoskip";
-                         else current_config<<"-frameskip"<<ui->comboBox_2->currentText();
-
-             if (ui->checkBox_6->isChecked())current_config<<"-showfps";
-             if (ui->checkBox_7->isChecked())current_config<<"-fullscreen";
-             if (ui->checkBox_8->isChecked())current_config<<"-abbeyfix";
-
-
-
-                   }
-         current_config<<"-runcd";
-     }
 }
 
 void options::psx4m_hwa_block(){
@@ -271,10 +280,12 @@ void options::psx4m_hwa_block(){
         ui->checkBox_7->setEnabled(false);
         ui->checkBox_8->setEnabled(false);
         ui->comboBox_2->setEnabled(false);
+        ui->checkBox_16->setEnabled(true);
     }else{
         ui->checkBox_6->setEnabled(true);
         ui->checkBox_7->setEnabled(true);
         ui->checkBox_8->setEnabled(true);
         ui->comboBox_2->setEnabled(true);
+        ui->checkBox_16->setEnabled(false);
     }
 }
